@@ -16,5 +16,5 @@ static const char path[] = "/proc/acpi/ibm/light";
 
 int main()
 {
-	return chmod( path, 0777 );
+	return chmod( path, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH );
 }
