@@ -17,23 +17,20 @@
  */
 #include "thinklightpreferences.h"
 
-#include "thinklightconfig.h"
+#include "kopete_thinklight.h"
 
 #include <kgenericfactory.h>
 
-#include <qlayout.h>
+K_PLUGIN_FACTORY( ThinklightPreferencesFactory, registerPlugin<ThinklightPreferences>(); )
+K_EXPORT_PLUGIN( ThinklightPreferencesFactory( "kcm_kopete_thinklight" ) )
 
-typedef KGenericFactory<ThinkLightPreferences> ThinkLightPreferencesFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_kopete_thinklight, ThinkLightPreferencesFactory( "kcm_kopete_thinklight" )  )
-
-ThinkLightPreferences::ThinkLightPreferences( QWidget *parent, const char*, const QStringList &args ) :
-	KCModule( ThinkLightPreferencesFactory::instance(), parent, args ),
-	m_ui( this )
+ThinklightPreferences::ThinklightPreferences( QWidget *parent, const QVariantList &args ) :
+	KCModule( ThinklightPreferencesFactory::componentData(), parent, args )
 {
-	( new QVBoxLayout( this ) )->addWidget( &m_ui );
-
-	addConfig( ThinkLightConfig::self(), &m_ui );
+	setupUi( this );
 
+	addConfig( ThinklightKcfg::self(), this );
+	ThinklightKcfg::self()->readConfig();
 	load();
 }
 
