@@ -19,21 +19,18 @@
 #define THINKLIGHTPREFERENCES_H
 
 #include <kcmodule.h>
-#include "thinklightpreferencesui.h"
+#include "ui_thinklightpreferencesui.h"
 
 /**
- * @short Preferences KCModule for ThinkLightPlugin for Kopete.
+ * @short Preferences KCModule for ThinklightPlugin for Kopete.
  *
  * @author Bernhard Beschow
  */
-class ThinkLightPreferences : public KCModule
+class ThinklightPreferences : public KCModule, private Ui::ThinklightPreferencesUI
 {
 	Q_OBJECT
 public:
-	ThinkLightPreferences( QWidget *parent = 0, const char* = 0, const QStringList &args = QStringList() );
-
-protected:
-	ThinkLightPreferencesUI m_ui;
+	ThinklightPreferences( QWidget *parent = 0, const QVariantList &args = QVariantList() );
 };
 
 #endif
